# Event Outbox

The project is not production ready yet.

## Installation

With [pip](https://pypi.org/project/pip/):

```bash
pip install event-outbox
```

With [poetry](https://python-poetry.org/):

```bash
poetry add event-outbox
```

## Usage

See the proof-of-concept [example](https://github.com/returnnullptr/event-outbox-example).

## Development

```bash
bash cleanup.sh
```
